@@ -1,4 +1,3 @@
-# from .Function import FairFunction
 from .Queue import FairQueue
 from F import DICT
 
@@ -34,4 +33,7 @@ class FairCallbackChannel:
         self.subscribe(func)
         def wrapper(args):
             return func(args)
-        return wrapper
\ No newline at end of file
+        return wrapper
+
+class fcc(FairCallbackChannel):
+    pass
