@@ -8,7 +8,8 @@ Log = Log("FCoRE.DICT")
 -> "dict" object extension/helper functions
 """
 
-SORT_BY_VALUE = lambda dictObj: {k: v for k, v in sorted(dictObj.items(), key=lambda item: item[1], reverse=True)}
+SORT_BY_VALUE = lambda dictObj: {k: v for k, v in sorted(dictObj.items(), key=lambda item: item[1], reverse=False)}
+SORT_BY_KEY = lambda dictObj, reversed: {k: v for k, v in sorted(dictObj.items(), key=lambda item: item[0], reverse=reversed)}
 
 get_random = lambda dic: random.choice(list(dic.values()))
 
@@ -18,7 +19,15 @@ def yieldThis(dic:dict):
         yield key, value
 
 """ Master Search """
-def get(key: str, dic, default=False, depth=0):
+
+def get_any(keys:[], dic, default=None):
+    for key in keys:
+        temp = get(key, dic, default=None)
+        if temp:
+            return temp
+    return default
+
+def get(key: str, dic, default=None, depth=0):
     """
     Able to search embedded dict's for keys.
     Safely returns result or False.
@@ -220,6 +229,8 @@ def add_word_count(*dicts) -> dict:
     for dictionary in dicts:
         # Loop each key
         for key in dictionary.keys():
+            if dictionary == key:
+                continue
             if result.__contains__(key):
                 temp = result[key] + dictionary[key]
                 result[key] = temp
