@@ -4,7 +4,9 @@ from inspect import signature
 
 from F import LIST
 
-
+ifElse = lambda first, second: first if first else second
+# def ifElse(objOne, objTwo):
+#     return objOne if objOne else objTwo
 def get_uuid():
     return str(uuid.uuid4())
 
@@ -21,6 +23,15 @@ def get_function_name(obj):
         return obj.__name__
     return False
 
+def starts_with(obj, starting):
+    if str(obj).startswith(str(starting)):
+        return True
+    return False
+def ends_with(obj, ending):
+    if str(obj).endswith(str(ending)):
+        return True
+    return False
+
 def is_string(obj):
     if not obj:
         return False
@@ -126,5 +137,7 @@ def combine_args_str(*content: str) -> str:
     temp = ""
     content = LIST.flatten(content)
     for item in content:
+        if not item:
+            continue
         temp += " " + str(item)
     return str(temp).strip()
\ No newline at end of file
